==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkUnstructuredGridPreIntegration.java <==
// java wrapper for vtkUnstructuredGridPreIntegration object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGridPreIntegration extends vtkUnstructuredGridVolumeRayIntegrator
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2(vtkVolume id0,vtkDataArray id1);
  public void Initialize(vtkVolume id0,vtkDataArray id1)
    { Initialize_2(id0,id1); }

  private native void Integrate_3(vtkDoubleArray id0,vtkDataArray id1,vtkDataArray id2,double id3[]);
  public void Integrate(vtkDoubleArray id0,vtkDataArray id1,vtkDataArray id2,double id3[])
    { Integrate_3(id0,id1,id2,id3); }

  private native long GetIntegrator_4();
  public vtkUnstructuredGridVolumeRayIntegrator GetIntegrator() {
    long temp = GetIntegrator_4();

    if (temp == 0) return null;
    return (vtkUnstructuredGridVolumeRayIntegrator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetIntegrator_5(vtkUnstructuredGridVolumeRayIntegrator id0);
  public void SetIntegrator(vtkUnstructuredGridVolumeRayIntegrator id0)
    { SetIntegrator_5(id0); }

  private native void SetIntegrationTableScalarResolution_6(int id0);
  public void SetIntegrationTableScalarResolution(int id0)
    { SetIntegrationTableScalarResolution_6(id0); }

  private native int GetIntegrationTableScalarResolution_7();
  public int GetIntegrationTableScalarResolution()
    { return GetIntegrationTableScalarResolution_7(); }

  private native void SetIntegrationTableLengthResolution_8(int id0);
  public void SetIntegrationTableLengthResolution(int id0)
    { SetIntegrationTableLengthResolution_8(id0); }

  private native int GetIntegrationTableLengthResolution_9();
  public int GetIntegrationTableLengthResolution()
    { return GetIntegrationTableLengthResolution_9(); }

  private native double GetIntegrationTableScalarShift_10(int id0);
  public double GetIntegrationTableScalarShift(int id0)
    { return GetIntegrationTableScalarShift_10(id0); }

  private native double GetIntegrationTableScalarScale_11(int id0);
  public double GetIntegrationTableScalarScale(int id0)
    { return GetIntegrationTableScalarScale_11(id0); }

  private native double GetIntegrationTableLengthScale_12();
  public double GetIntegrationTableLengthScale()
    { return GetIntegrationTableLengthScale_12(); }

  private native int GetIncrementalPreIntegration_13();
  public int GetIncrementalPreIntegration()
    { return GetIncrementalPreIntegration_13(); }

  private native void SetIncrementalPreIntegration_14(int id0);
  public void SetIncrementalPreIntegration(int id0)
    { SetIncrementalPreIntegration_14(id0); }

  private native void IncrementalPreIntegrationOn_15();
  public void IncrementalPreIntegrationOn()
    { IncrementalPreIntegrationOn_15(); }

  private native void IncrementalPreIntegrationOff_16();
  public void IncrementalPreIntegrationOff()
    { IncrementalPreIntegrationOff_16(); }

  public vtkUnstructuredGridPreIntegration() { super(); }

  public vtkUnstructuredGridPreIntegration(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-aarch64.pkg.tar.xz: vtk/vtkUnstructuredGridPreIntegration.java <==
// java wrapper for vtkUnstructuredGridPreIntegration object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGridPreIntegration extends vtkUnstructuredGridVolumeRayIntegrator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2(vtkVolume id0,vtkDataArray id1);
  public void Initialize(vtkVolume id0,vtkDataArray id1)
    { Initialize_2(id0,id1); }

  private native void Integrate_3(vtkDoubleArray id0,vtkDataArray id1,vtkDataArray id2,double id3[]);
  public void Integrate(vtkDoubleArray id0,vtkDataArray id1,vtkDataArray id2,double id3[])
    { Integrate_3(id0,id1,id2,id3); }

  private native long GetIntegrator_4();
  public vtkUnstructuredGridVolumeRayIntegrator GetIntegrator() {
    long temp = GetIntegrator_4();

    if (temp == 0) return null;
    return (vtkUnstructuredGridVolumeRayIntegrator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetIntegrator_5(vtkUnstructuredGridVolumeRayIntegrator id0);
  public void SetIntegrator(vtkUnstructuredGridVolumeRayIntegrator id0)
    { SetIntegrator_5(id0); }

  private native void SetIntegrationTableScalarResolution_6(int id0);
  public void SetIntegrationTableScalarResolution(int id0)
    { SetIntegrationTableScalarResolution_6(id0); }

  private native int GetIntegrationTableScalarResolution_7();
  public int GetIntegrationTableScalarResolution()
    { return GetIntegrationTableScalarResolution_7(); }

  private native void SetIntegrationTableLengthResolution_8(int id0);
  public void SetIntegrationTableLengthResolution(int id0)
    { SetIntegrationTableLengthResolution_8(id0); }

  private native int GetIntegrationTableLengthResolution_9();
  public int GetIntegrationTableLengthResolution()
    { return GetIntegrationTableLengthResolution_9(); }

  private native double GetIntegrationTableScalarShift_10(int id0);
  public double GetIntegrationTableScalarShift(int id0)
    { return GetIntegrationTableScalarShift_10(id0); }

  private native double GetIntegrationTableScalarScale_11(int id0);
  public double GetIntegrationTableScalarScale(int id0)
    { return GetIntegrationTableScalarScale_11(id0); }

  private native double GetIntegrationTableLengthScale_12();
  public double GetIntegrationTableLengthScale()
    { return GetIntegrationTableLengthScale_12(); }

  private native int GetIncrementalPreIntegration_13();
  public int GetIncrementalPreIntegration()
    { return GetIncrementalPreIntegration_13(); }

  private native void SetIncrementalPreIntegration_14(int id0);
  public void SetIncrementalPreIntegration(int id0)
    { SetIncrementalPreIntegration_14(id0); }

  private native void IncrementalPreIntegrationOn_15();
  public void IncrementalPreIntegrationOn()
    { IncrementalPreIntegrationOn_15(); }

  private native void IncrementalPreIntegrationOff_16();
  public void IncrementalPreIntegrationOff()
    { IncrementalPreIntegrationOff_16(); }

  public vtkUnstructuredGridPreIntegration() { super(); }

  public vtkUnstructuredGridPreIntegration(long id) { super(id); }
  public native long   VTKInit();

}
